/*
 * Copyright (c) 2015-2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef HDC2010_H_
#define HDC2010_H_

#include "sce/scif.h"
#include "stdint.h"


typedef void(*SceTmp_tmpCallback)(uint16_t tmpValue, uint16_t tmpSign);

/* Intializes the SCE TMP sampling task.
 *
 * This loads the SCE with the HDC sampling task, sets the sampling time.
 *  * The Minimum Report Interval will be used to send sensor data on a minimum interval in case the sensor
 * data does not change within this time. The Minimum Report Interval can be set to 0 if no minimum
 * report interval is required.
 *
 * Note that this does not start the task, see SceTmp_start for starting a task.
 */
void SceTmp_init(uint32_t samplingTime, uint32_t minReportInterval);

/* Sets the SCE HDC sampling task report interval.
 * The Minimum Report Interval will be used to send sensor data on a minimum interval in case sensor
 * data does not change within this time. The Minimum Report Interval can be set to 0 if no minimum
 * report interval is required.
 *
 * Note that this can be called after the task has been started.
 */
void SceTmp_setReportInterval(uint32_t minReportInterval);

/* Register the callback used for receiving the updated TMP value.
 * Note that only one callback may be registered at a time.
 */
void SceTmp_registerTmpCallback(SceTmp_tmpCallback callback);

/* Starts the SCE TMP sampling task.
 *
 * The task has to be initialized using SceAdc_init before being started. */
void SceTmp_start(void);


#endif /* SCEADC_H_ */
